/* Project name:
     Button_Test (Sample usage of Button() function)
 * Copyright:
     (c) mikroElektronika, 2011.
 * Revision History:
     20110117:
       - Initial release (TL);
 * Description:
     This example detects the transition from logical one to logical zero
     on input pin RD0.
 * Test configuration:
     MCU:             dsPIC30F4013
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70138F.pdf
     Dev.Board:       BIGdsPIC6
                      http://www.mikroe.com/eng/products/view/483/bigdspic6-development-system/
     Oscillator:      XT-PLL8, 10.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for dsPIC30/33 and PIC24 v4.60
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
     - Turn on LEDs on PORTB at SW11 and pull down on PORTD at SW5 (board specific).
 */

bit oldstate;

void main() {
  ADPCFG = 0xFFFF;                             // initialize AN pins as digital
  TRISD = 0xFFFF;                              // initialize portD as input
  TRISB = 0x0000;                              // initialize portB as output

  do {
    if (Button(&PORTD, 0, 1, 1))               // detect logical one state
      oldstate = 1;
    if (oldstate && Button(&PORTD, 0, 1, 0)) { // detect logical one to logical zero transition
      LATB = ~LATB;                            // toggle portb
      oldstate = 0;
    }
  } while(1);
}