/* Project name:
     RTC_Write (Writing date/time data to PCF8583 through I2C)
 * Copyright:
     (c) mikroElektronika, 2011.
 * Revision History:
     20110117:
       - Initial release (TL);
 * Description:
     This project is simple demonstration how to set date and time on PCF8583
     RTC (real-time clock).
     The example sets the following:
       TIME: 12:00:00
       DATE: 01/17/2011
     Please refer to PCF8583 datasheet for more information on config. word and
     time format settings.
 * Test configuration:
     MCU:             dsPIC30F6014A
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70143D.pdf
     Dev.Board:       BIGdsPIC6
                      http://www.mikroe.com/eng/products/view/483/bigdspic6-development-system/
     Oscillator:      XT-PLL8, 10.000MHz
     Ext. Modules:    LCD 2x16 chars
     SW:              mikroC PRO for dsPIC30/33 and PIC24 v4.60
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
     - Turn on I2C communication switches at SW12 (SW12.3 and SW12.4).
 */

void main() {

  ADPCFG = 0xFFFF;

   Delay_ms(1000);

   I2C1_Init(100000);     // initialize full master mode
   I2C1_Start();          // issue start signal
   I2C1_Write(0xD0);      // address DS1307
   I2C1_Write(0);         // start from word at address (REG0)
   I2C1_Write(0x80);      // write $80 to REG0. (pause counter + 0 sec)
   I2C1_Write(0);         // write 0 to minutes word to (REG1)
   I2C1_Write(0x12);      // write 12 to hours word (24-hours mode)(REG2)
   I2C1_Write(0x02);      // write 2 - Monday (REG3)
   I2C1_Write(0x17);      // write 17 to date word (REG4)
   I2C1_Write(0x01);      // write 1 (January) to month word (REG5)
   I2C1_Write(0x11);      // write 11 to year word (REG6)
   I2C1_Stop();           // issue stop signal

   I2C1_Start();          // issue start signal
   I2C1_Write(0xD0);      // address DS1307
   I2C1_Write(0);         // start from word at address 0
   I2C1_Write(0);         // write 0 to REG0 (enable counting + 0 sec)
   I2C1_Stop();           // issue stop signal
}